# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.tcm.v20210413 import models


class TcmClient(AbstractClient):
    _apiVersion = '2021-04-13'
    _endpoint = 'tcm.tencentcloudapi.com'
    _service = 'tcm'


    def CreateMesh(self, request):
        """创建网格

        :param request: Request instance for CreateMesh.
        :type request: :class:`tencentcloud.tcm.v20210413.models.CreateMeshRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.CreateMeshResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateMesh", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateMeshResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteMesh(self, request):
        """删除网格

        :param request: Request instance for DeleteMesh.
        :type request: :class:`tencentcloud.tcm.v20210413.models.DeleteMeshRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.DeleteMeshResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteMesh", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteMeshResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeAccessLogConfig(self, request):
        """获取AccessLog配置

        :param request: Request instance for DescribeAccessLogConfig.
        :type request: :class:`tencentcloud.tcm.v20210413.models.DescribeAccessLogConfigRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.DescribeAccessLogConfigResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeAccessLogConfig", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeAccessLogConfigResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeMesh(self, request):
        """查询网格详情

        :param request: Request instance for DescribeMesh.
        :type request: :class:`tencentcloud.tcm.v20210413.models.DescribeMeshRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.DescribeMeshResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeMesh", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeMeshResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeMeshList(self, request):
        """查询网格列表

        :param request: Request instance for DescribeMeshList.
        :type request: :class:`tencentcloud.tcm.v20210413.models.DescribeMeshListRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.DescribeMeshListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeMeshList", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeMeshListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def LinkClusterList(self, request):
        """关联集群

        :param request: Request instance for LinkClusterList.
        :type request: :class:`tencentcloud.tcm.v20210413.models.LinkClusterListRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.LinkClusterListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("LinkClusterList", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.LinkClusterListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def LinkPrometheus(self, request):
        """关联Prometheus

        :param request: Request instance for LinkPrometheus.
        :type request: :class:`tencentcloud.tcm.v20210413.models.LinkPrometheusRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.LinkPrometheusResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("LinkPrometheus", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.LinkPrometheusResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyAccessLogConfig(self, request):
        """修改访问日志配置

        :param request: Request instance for ModifyAccessLogConfig.
        :type request: :class:`tencentcloud.tcm.v20210413.models.ModifyAccessLogConfigRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.ModifyAccessLogConfigResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyAccessLogConfig", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyAccessLogConfigResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyMesh(self, request):
        """修改网格

        :param request: Request instance for ModifyMesh.
        :type request: :class:`tencentcloud.tcm.v20210413.models.ModifyMeshRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.ModifyMeshResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyMesh", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyMeshResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyTracingConfig(self, request):
        """修改 Tracing 配置

        :param request: Request instance for ModifyTracingConfig.
        :type request: :class:`tencentcloud.tcm.v20210413.models.ModifyTracingConfigRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.ModifyTracingConfigResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyTracingConfig", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyTracingConfigResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def UnlinkCluster(self, request):
        """解关联集群

        :param request: Request instance for UnlinkCluster.
        :type request: :class:`tencentcloud.tcm.v20210413.models.UnlinkClusterRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.UnlinkClusterResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UnlinkCluster", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.UnlinkClusterResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def UnlinkPrometheus(self, request):
        """解除关联Prometheus

        :param request: Request instance for UnlinkPrometheus.
        :type request: :class:`tencentcloud.tcm.v20210413.models.UnlinkPrometheusRequest`
        :rtype: :class:`tencentcloud.tcm.v20210413.models.UnlinkPrometheusResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UnlinkPrometheus", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.UnlinkPrometheusResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.smh.v20210712 import models


class SmhClient(AbstractClient):
    _apiVersion = '2021-07-12'
    _endpoint = 'smh.tencentcloudapi.com'
    _service = 'smh'


    def CreateLibrary(self, request):
        """创建 PaaS 服务媒体库

        :param request: Request instance for CreateLibrary.
        :type request: :class:`tencentcloud.smh.v20210712.models.CreateLibraryRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.CreateLibraryResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateLibrary", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateLibraryResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteLibrary(self, request):
        """删除 PaaS 服务媒体库

        :param request: Request instance for DeleteLibrary.
        :type request: :class:`tencentcloud.smh.v20210712.models.DeleteLibraryRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DeleteLibraryResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteLibrary", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteLibraryResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeLibraries(self, request):
        """查询 PaaS 服务媒体库列表

        :param request: Request instance for DescribeLibraries.
        :type request: :class:`tencentcloud.smh.v20210712.models.DescribeLibrariesRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DescribeLibrariesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeLibraries", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeLibrariesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeLibrarySecret(self, request):
        """查询 PaaS 服务媒体库密钥

        :param request: Request instance for DescribeLibrarySecret.
        :type request: :class:`tencentcloud.smh.v20210712.models.DescribeLibrarySecretRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DescribeLibrarySecretResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeLibrarySecret", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeLibrarySecretResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeOfficialInstances(self, request):
        """查询官方云盘实例

        :param request: Request instance for DescribeOfficialInstances.
        :type request: :class:`tencentcloud.smh.v20210712.models.DescribeOfficialInstancesRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DescribeOfficialInstancesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeOfficialInstances", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeOfficialInstancesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeOfficialOverview(self, request):
        """查询官方云盘实例概览数据

        :param request: Request instance for DescribeOfficialOverview.
        :type request: :class:`tencentcloud.smh.v20210712.models.DescribeOfficialOverviewRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DescribeOfficialOverviewResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeOfficialOverview", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeOfficialOverviewResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeTrafficPackages(self, request):
        """查询流量资源包

        :param request: Request instance for DescribeTrafficPackages.
        :type request: :class:`tencentcloud.smh.v20210712.models.DescribeTrafficPackagesRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.DescribeTrafficPackagesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeTrafficPackages", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeTrafficPackagesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ModifyLibrary(self, request):
        """修改 PaaS 服务媒体库配置项

        :param request: Request instance for ModifyLibrary.
        :type request: :class:`tencentcloud.smh.v20210712.models.ModifyLibraryRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.ModifyLibraryResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ModifyLibrary", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ModifyLibraryResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SendSmsCode(self, request):
        """发送用于换绑官方云盘实例的超级管理员账号的短信验证码

        :param request: Request instance for SendSmsCode.
        :type request: :class:`tencentcloud.smh.v20210712.models.SendSmsCodeRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.SendSmsCodeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SendSmsCode", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SendSmsCodeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def VerifySmsCode(self, request):
        """验证短信验证码以换绑官方云盘实例的超级管理员账号

        :param request: Request instance for VerifySmsCode.
        :type request: :class:`tencentcloud.smh.v20210712.models.VerifySmsCodeRequest`
        :rtype: :class:`tencentcloud.smh.v20210712.models.VerifySmsCodeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("VerifySmsCode", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.VerifySmsCodeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 操作失败。
FAILEDOPERATION = 'FailedOperation'

# 告警策略通知模板已经绑定到了某个告警策略上。
FAILEDOPERATION_BINDEDALARM = 'FailedOperation.BindedAlarm'

# 检索日志触发最大条数限制。
FAILEDOPERATION_GETLOGREACHLIMIT = 'FailedOperation.GetlogReachLimit'

# 低频不支持配置kv和tag索引。
FAILEDOPERATION_INVALIDINDEXRULEFORSEARCHLOW = 'FailedOperation.InValidIndexRuleForSearchLow'

# 该告警策略状态异常，请检查下日志主题ID是否都存在。
FAILEDOPERATION_INVALIDALARM = 'FailedOperation.InvalidAlarm'

# 检索游标已失效或不存在。
FAILEDOPERATION_INVALIDCONTEXT = 'FailedOperation.InvalidContext'

# 离线存储保存时间不得少于7天。
FAILEDOPERATION_INVALIDPERIOD = 'FailedOperation.InvalidPeriod'

# 相同的日志集已存在。
FAILEDOPERATION_LOGSETCONFLICT = 'FailedOperation.LogsetConflict'

# 日志集下存在日志主题。
FAILEDOPERATION_LOGSETNOTEMPTY = 'FailedOperation.LogsetNotEmpty'

# 无效的Content。
FAILEDOPERATION_MISSINGCONTENT = 'FailedOperation.MissingContent'

# 修改的生命周期被禁止。
FAILEDOPERATION_PERIODMODIFYFORBIDDEN = 'FailedOperation.PeriodModifyForbidden'

# 查询语句运行失败。
FAILEDOPERATION_QUERYERROR = 'FailedOperation.QueryError'

# 读qps超过限制。
FAILEDOPERATION_READQPSLIMIT = 'FailedOperation.ReadQpsLimit'

# 查询超时。
FAILEDOPERATION_SEARCHTIMEOUT = 'FailedOperation.SearchTimeout'

# 投递任务不允许重试。
FAILEDOPERATION_SHIPPERTASKNOTTORETRY = 'FailedOperation.ShipperTaskNotToRetry'

# 查询语句解析错误。
FAILEDOPERATION_SYNTAXERROR = 'FailedOperation.SyntaxError'

# 请求标签服务限频。
FAILEDOPERATION_TAGQPSLIMIT = 'FailedOperation.TagQpsLimit'

# 日志主题已关闭。
FAILEDOPERATION_TOPICCLOSED = 'FailedOperation.TopicClosed'

# 日志主题已隔离。
FAILEDOPERATION_TOPICISOLATED = 'FailedOperation.TopicIsolated'

# 写qps超过限制。
FAILEDOPERATION_WRITEQPSLIMIT = 'FailedOperation.WriteQpsLimit'

# 写流量超过限制。
FAILEDOPERATION_WRITETRAFFICLIMIT = 'FailedOperation.WriteTrafficLimit'

# 内部错误。
INTERNALERROR = 'InternalError'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 告警策略已经存在。
INVALIDPARAMETER_ALARMCONFLICT = 'InvalidParameter.AlarmConflict'

# 告警策略通知模板已经存在。
INVALIDPARAMETER_ALARMNOTICECONFLICT = 'InvalidParameter.AlarmNoticeConflict'

# 相同的采集配置规则已经存在。
INVALIDPARAMETER_CONFIGCONFLICT = 'InvalidParameter.ConfigConflict'

# 无效的Content。
INVALIDPARAMETER_CONTENT = 'InvalidParameter.Content'

# 数据库唯一键冲突。
INVALIDPARAMETER_DBDUPLICATION = 'InvalidParameter.DbDuplication'

# 导出任务已经存在。
INVALIDPARAMETER_EXPORTCONFLICT = 'InvalidParameter.ExportConflict'

# 低频不支持配置kv和tag索引。
INVALIDPARAMETER_INVALIDINDEXRULEFORSEARCHLOW = 'InvalidParameter.InValidIndexRuleForSearchLow'

# 指定日志主题已经存在索引规则。
INVALIDPARAMETER_INDEXCONFLICT = 'InvalidParameter.IndexConflict'

# 相同的日志集已存在。
INVALIDPARAMETER_LOGSETCONFLICT = 'InvalidParameter.LogsetConflict'

# 同名机器组已经存在。
INVALIDPARAMETER_MACHINEGROUPCONFLICT = 'InvalidParameter.MachineGroupConflict'

# 投递规则命名冲突。
INVALIDPARAMETER_SHIPPERCONFLICT = 'InvalidParameter.ShipperConflict'

# 指定日志集下已经有同名的日志主题。
INVALIDPARAMETER_TOPICCONFLICT = 'InvalidParameter.TopicConflict'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 超过配额限制。
LIMITEXCEEDED = 'LimitExceeded'

# 采集规则配置超过最大值限制。
LIMITEXCEEDED_CONFIG = 'LimitExceeded.Config'

# 日志导出数量超出限制。
LIMITEXCEEDED_EXPORT = 'LimitExceeded.Export'

# 并发查询超过限制，单topic并发最大值15。
LIMITEXCEEDED_LOGSEARCH = 'LimitExceeded.LogSearch'

# 日志大小超过限制。
LIMITEXCEEDED_LOGSIZE = 'LimitExceeded.LogSize'

# 日志集数量超出限制。
LIMITEXCEEDED_LOGSET = 'LimitExceeded.Logset'

# 机器组超过限制。
LIMITEXCEEDED_MACHINEGROUP = 'LimitExceeded.MachineGroup'

# 机器组IP超过限制。
LIMITEXCEEDED_MACHINEGROUPIP = 'LimitExceeded.MachineGroupIp'

# 机器组Label超过限制。
LIMITEXCEEDED_MACHINEGROUPIPLABELS = 'LimitExceeded.MachineGroupIpLabels'

# 分区超过限制。
LIMITEXCEEDED_PARTITION = 'LimitExceeded.Partition'

# 检索内存超限。
LIMITEXCEEDED_SEARCHRESOURCES = 'LimitExceeded.SearchResources'

# 检索接口返回的日志量太大， 超过20MB限制。
LIMITEXCEEDED_SEARCHRESULTTOOLARGE = 'LimitExceeded.SearchResultTooLarge'

# 投递规则超出限制。
LIMITEXCEEDED_SHIPPER = 'LimitExceeded.Shipper'

# tag超过限制。
LIMITEXCEEDED_TAG = 'LimitExceeded.Tag'

# 日志主题数目超过限制。
LIMITEXCEEDED_TOPIC = 'LimitExceeded.Topic'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 操作被拒绝。
OPERATIONDENIED = 'OperationDenied'

# ACL校验失败。
OPERATIONDENIED_ACLFAILED = 'OperationDenied.ACLFailed'

# 账户已销毁。
OPERATIONDENIED_ACCOUNTDESTROY = 'OperationDenied.AccountDestroy'

# 账户欠费。
OPERATIONDENIED_ACCOUNTISOLATE = 'OperationDenied.AccountIsolate'

# 账户不存在。
OPERATIONDENIED_ACCOUNTNOTEXISTS = 'OperationDenied.AccountNotExists'

# 低频不支持告警。
OPERATIONDENIED_ALARMNOTSUPPORTFORSEARCHLOW = 'OperationDenied.AlarmNotSupportForSearchLow'

# 字段没有开启分析功能。
OPERATIONDENIED_ANALYSISSWITCHCLOSE = 'OperationDenied.AnalysisSwitchClose'

# 不支持新语法。
OPERATIONDENIED_NEWSYNTAXNOTSUPPORTED = 'OperationDenied.NewSyntaxNotSupported'

# 通知模板已绑定告警，无法删除。
OPERATIONDENIED_NOTICEHASALARM = 'OperationDenied.NoticeHasAlarm'

# 操作低频检索不支持。
OPERATIONDENIED_OPERATIONNOTSUPPORTINSEARCHLOW = 'OperationDenied.OperationNotSupportInSearchLow'

# topic绑定了数据加工。
OPERATIONDENIED_TOPICHASDATAFORMTASK = 'OperationDenied.TopicHasDataFormTask'

# topic绑定了函数投递。
OPERATIONDENIED_TOPICHASDELIVERFUNCTION = 'OperationDenied.TopicHasDeliverFunction'

# topic绑定了scheduleSql任务。
OPERATIONDENIED_TOPICHASSCHEDULESQLTASK = 'OperationDenied.TopicHasScheduleSqlTask'

# 资源不存在。
RESOURCENOTFOUND = 'ResourceNotFound'

# agent version不存在。
RESOURCENOTFOUND_AGENTVERSIONNOTEXIST = 'ResourceNotFound.AgentVersionNotExist'

# 告警策略不存在。
RESOURCENOTFOUND_ALARMNOTEXIST = 'ResourceNotFound.AlarmNotExist'

# 告警策略通知模板不存在。
RESOURCENOTFOUND_ALARMNOTICENOTEXIST = 'ResourceNotFound.AlarmNoticeNotExist'

# 指定的采集规则配置不存在。
RESOURCENOTFOUND_CONFIGNOTEXIST = 'ResourceNotFound.ConfigNotExist'

# 日志导出不存在。
RESOURCENOTFOUND_EXPORTNOTEXIST = 'ResourceNotFound.ExportNotExist'

# 索引不存在。
RESOURCENOTFOUND_INDEXNOTEXIST = 'ResourceNotFound.IndexNotExist'

# 指定的日志集不存在。
RESOURCENOTFOUND_LOGSETNOTEXIST = 'ResourceNotFound.LogsetNotExist'

# 机器组不存在。
RESOURCENOTFOUND_MACHINEGROUPNOTEXIST = 'ResourceNotFound.MachineGroupNotExist'

# 分区不存在。
RESOURCENOTFOUND_PARTITIONNOTEXIST = 'ResourceNotFound.PartitionNotExist'

# 投递规则不存在。
RESOURCENOTFOUND_SHIPPERNOTEXIST = 'ResourceNotFound.ShipperNotExist'

# 投递任务不存在。
RESOURCENOTFOUND_SHIPPERTASKNOTEXIST = 'ResourceNotFound.ShipperTaskNotExist'

# 日志主题不存在。
RESOURCENOTFOUND_TOPICNOTEXIST = 'ResourceNotFound.TopicNotExist'

# 操作不支持。
UNSUPPORTEDOPERATION = 'UnsupportedOperation'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.tiia.v20190529 import models


class TiiaClient(AbstractClient):
    _apiVersion = '2019-05-29'
    _endpoint = 'tiia.tencentcloudapi.com'
    _service = 'tiia'


    def AssessQuality(self, request):
        """评估输入图片在视觉上的质量，从多个方面评估，并同时给出综合的、客观的清晰度评分，和主观的美观度评分。

        >
        - 可前往 [图像处理](https://cloud.tencent.com/document/product/1590) 产品文档中查看更多产品信息。
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for AssessQuality.
        :type request: :class:`tencentcloud.tiia.v20190529.models.AssessQualityRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.AssessQualityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("AssessQuality", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.AssessQualityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateGroup(self, request):
        """本接口用于创建一个空的图片库，图片库主要用于存储在创建图片时提取的图片特征数据，如果图片库已存在则返回错误。不同的图片库类型对应不同的图像搜索服务类型，根据输入参数GroupType区分。

        <table>
            <th>服务类型</th><th>GroupType</th><th>功能描述</th>
            <tr>
                <td>通用图像搜索</td>
                <td>4</td>
                <td>通用图像搜索1.0版。<br>在自建图片库中搜索相同原图或相似图片集，并给出相似度打分，可支持裁剪、翻转、调色、加水印等二次编辑后的图片搜索。适用于图片版权保护、原图查询等场景。</td>
            </tr>
            <tr>
                <td rowspan="2">商品图像搜索</td>
                <td>7</td><td>商品图像搜索2.0升级版。<br>
                在自建图库中搜索同款或相似商品，并给出相似度打分。对于服饰类商品可支持识别服饰类别、属性等信息。适用于商品分类、检索、推荐等电商场景。</td>
            </tr>
             <tr>
                <td>5</td>
                <td>商品图像搜索1.0版。<br>
                功能和2.0升级版类似。</td>
            </tr>
            <tr>
            <td>图案花纹搜索</td><td>6</td><td>图案花纹搜索1.0版。<br>
            在自建图库中搜索相似的图案、logo、纹理等图像元素或主体，并给出相似度打分。</td>
            </tr>
        </table>

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。


        :param request: Request instance for CreateGroup.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CreateGroupRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CreateGroupResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateGroup", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateGroupResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateImage(self, request):
        """创建图片，并添加对应图片的自定义信息。模型将在创建图片时自动提取图像特征并存储到指定的图片库中，每创建一张图片会对应提取和存储一条图片特征数据。

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。


        :param request: Request instance for CreateImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CreateImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CreateImageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateImage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CropImage(self, request):
        """根据输入的裁剪比例，智能判断一张图片的最佳裁剪区域，确保原图的主体区域不受影响，以适应不同平台、设备的展示要求，避免简单拉伸带来的变形。

        >
        - 可前往 [图像处理](https://cloud.tencent.com/document/product/1590) 产品文档中查看更多产品信息。
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for CropImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.CropImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.CropImageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CropImage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CropImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteImages(self, request):
        """删除图片。

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。

        :param request: Request instance for DeleteImages.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DeleteImagesRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DeleteImagesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteImages", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteImagesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeGroups(self, request):
        """查询所有的图库信息。

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。

        :param request: Request instance for DescribeGroups.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DescribeGroupsRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DescribeGroupsResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeGroups", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeGroupsResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DescribeImages(self, request):
        """获取指定图片库中的图片列表。

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。

        :param request: Request instance for DescribeImages.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DescribeImagesRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DescribeImagesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DescribeImages", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DescribeImagesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectChefDress(self, request):
        """可对图片中厨师穿戴进行识别，支持厨师服识别，厨师帽识别，赤膊识别和口罩识别,可应用于明厨亮灶场景。
        "被优选过滤"标签值在人体优选开关开启时才会返回。
        厨师服：厨师服定义为白色上衣
        厨师服识别(酒店版)：厨师服定义为红色，白色，黑色上衣

        |序号 | 标签名称 | 标签值 |
        | :-----|  :----------   |:-----------------  |
        | 1 | 厨师服识别<div style="width: 70pt"> |无厨师服、有厨师服、被优选过滤|
        | 2 | 厨师服识别（酒店版）<div style="width: 70pt"> |无厨师服、有厨师服、被优选过滤|
        | 3 | 厨师帽识别<div style="width: 70pt"> |无厨师帽、有厨师帽、被优选过滤	|
        | 4 | 赤膊识别<div style="width: 70pt"> |非赤膊、赤膊、被优选过滤|
        | 5 | 口罩识别<div style="width: 70pt"> |无口罩、有口罩、口罩不确定、被优选过滤	|

        :param request: Request instance for DetectChefDress.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectChefDressRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectChefDressResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectChefDress", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectChefDressResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectDisgust(self, request):
        """输入一张图片，返回AI针对一张图片是否是恶心的一系列判断值。

        通过恶心图片识别, 可以判断一张图片是否令人恶心, 同时给出它属于的潜在类别, 让您能够过滤掉使人不愉快的图片。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectDisgust.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectDisgustRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectDisgustResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectDisgust", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectDisgustResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectEnvelope(self, request):
        """文件封识别可检测图片中是否包含符合文件封（即文件、单据、资料等的袋状包装）特征的物品，覆盖顺丰快递文件封、文件袋、档案袋等多种文件封类型，可应用于物流行业对文件快递的包装审核等场景。

        >?
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectEnvelope.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectEnvelopeRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectEnvelopeResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectEnvelope", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectEnvelopeResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectLabel(self, request):
        """图像标签利用深度学习技术，可以对图片进行智能分类、物体识别等。

        目前支持八个大类、六十多个子类、数千个标签，涵盖各种日常场景、动植物、物品、美食等。

        图像标签提供四个版本供选择：

        • 摄像头版：针对搜索、手机摄像头照片进行优化，涵盖大量卡证、日常物品、二维码条形码。

        • 相册版：针对手机相册、网盘进行优化，去除相册和网盘中不常见的标签，针对相册常见图片类型（人像、日常活动、日常物品等）识别效果更好。

        • 网络版：针对网络图片进行优化，涵盖标签更多，满足长尾识别需求。

        • 新闻版：针对新闻、资讯、广电等行业进行优化，增加定制识别，支持万级图像标签。

        为了方便使用、减少图片传输次数，图像标签将不同版本包装成多合一接口，实际上是多个服务，分别计费。建议在接入初期，对四个版本进行对比评估后选择合适的版本使用。

        >?
        - 图像标签已升级服务，建议使用新版接口[通用图像标签](https://cloud.tencent.com/document/product/865/75196)。
        - 图像标签摄像头版、相册版、网络版、新闻版分别按照各自的实际使用次数进行收费，例如一张图片同时使用相册版、摄像头版，则按照两次调用计费。建议测试对比后从中选择一个最合适的版本使用即可。

        >
        - 可前往 [图像标签](https://cloud.tencent.com/document/product/1588) 产品文档中查看更多产品信息。
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectLabel.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectLabelRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectLabelResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectLabel", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectLabelResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectLabelBeta(self, request):
        """图像标签测试接口

        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectLabelBeta.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectLabelBetaRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectLabelBetaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectLabelBeta", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectLabelBetaResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectLabelPro(self, request):
        """通用图像标签可识别数千种常见物体或场景，覆盖日常物品、场景、动物、植物、食物、饮品、交通工具等多个大类，返回主体的标签名称和所属细分类目等。

        >
        - 可前往 [图像标签](https://cloud.tencent.com/document/product/1588) 产品文档中查看更多产品信息。
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectLabelPro.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectLabelProRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectLabelProResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectLabelPro", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectLabelProResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectMisbehavior(self, request):
        """可以识别输入的图片中是否包含不良行为，例如打架斗殴、赌博、抽烟等，可以应用于广告图、直播截图、短视频截图等审核，减少不良行为对平台内容质量的影响，维护健康向上的互联网环境。
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectMisbehavior.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectMisbehaviorRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectMisbehaviorResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectMisbehavior", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectMisbehaviorResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectPet(self, request):
        """传入一张图片，识别出图片中是否存在宠物
        >
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectPet.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectPetRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectPetResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectPet", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectPetResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectProduct(self, request):
        """本接口支持识别图片中包含的商品，能够输出商品的品类名称、类别，还可以输出商品在图片中的位置。支持一张图片多个商品的识别。
        >?
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectProduct.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectProductRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectProductResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectProduct", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectProductResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectProductBeta(self, request):
        """商品识别-微信识物版，基于人工智能技术、海量训练图片、亿级商品库，可以实现全覆盖、细粒度、高准确率的商品识别和商品推荐功能。
        本服务可以识别出图片中的主体位置、主体商品类型，覆盖亿级SKU，输出具体商品的价格、型号等详细信息。
        客户无需自建商品库，即可快速实现商品识别、拍照搜商品等功能。
        >?
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for DetectProductBeta.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectProductBetaRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectProductBetaResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectProductBeta", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectProductBetaResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DetectSecurity(self, request):
        """识别常安全属性识别可对图片中人体安全防护属性进行识别，支持识别安全帽，反光衣，护目镜，工服，手套，工地安全带，口罩，抽烟，玩手机等多种属性。
        "被优选过滤"标签值在人体优选开关开启时才会返回。

        |序号 | 标签名称 | 标签值 |
        | :-----|  :----------   |:-----------------  |
        | 1 | 安全帽识别<div style="width: 70pt"> |无安全帽、有安全帽、被优选过滤|
        | 2 | 玩手机识别<div style="width: 70pt"> |没有电话、打电话、玩手机、被优选过滤|
        | 3 | 抽烟识别<div style="width: 70pt"> |没有抽烟、抽烟、被优选过滤	|
        | 4 | 口罩识别<div style="width: 70pt"> |无口罩、有口罩、口罩不确定、被优选过滤|
        | 5 | 工地安全带识别<div style="width: 70pt"> |无工地安全带、工地安全带、被优选过滤	|
        | 6 | 手套识别<div style="width: 70pt"> |无手套、有手套、手套不确定、被优选过滤	|
        | 7 | 工服识别<div style="width: 70pt"> |无工服、有工服、被优选过滤|
        | 8 | 护目镜识别<div style="width: 70pt"> |无护目镜、有护目镜、被优选过滤|
        | 9 | 反光衣识别<div style="width: 70pt"> |无反光衣、有反光衣、被优选过滤|

        :param request: Request instance for DetectSecurity.
        :type request: :class:`tencentcloud.tiia.v20190529.models.DetectSecurityRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.DetectSecurityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DetectSecurity", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DetectSecurityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def EnhanceImage(self, request):
        """传入一张图片，输出清晰度提升后的图片。

        可以消除图片有损压缩导致的噪声，和使用滤镜、拍摄失焦导致的模糊。让图片的边缘和细节更加清晰自然。

        >
        - 可前往 [图像处理](https://cloud.tencent.com/document/product/1590) 产品文档中查看更多产品信息。
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for EnhanceImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.EnhanceImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.EnhanceImageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("EnhanceImage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.EnhanceImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def RecognizeCar(self, request):
        """车辆识别可对图片中车辆的车型进行识别，输出车辆的品牌（如路虎）、车系（如神行者2）、类型（如中型SUV）、颜色和车辆在图中的坐标等信息，覆盖轿车、SUV、大型客车等市面常见车，支持三千多种车辆型号。如果图片中存在多辆车，会分别输出每辆车的车型和坐标。

        >?
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for RecognizeCar.
        :type request: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("RecognizeCar", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.RecognizeCarResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def RecognizeCarPro(self, request):
        """车辆识别（增强版）在车辆识别的基础上**增加了车牌识别的功能，并升级了车型识别的效果**。可对图片中车辆的车型和车牌进行同时识别，输出车辆的车牌信息，以及车辆品牌（如路虎）、车系（如神行者2）、类型（如中型SUV）、颜色和车辆在图中的坐标等信息，覆盖轿车、SUV、大型客车等市面常见车，支持三千多种车辆型号。如果图片中存在多辆车，会分别输出每辆车的车型、车牌和坐标。

        >?
        - 公共参数中的签名方式必须指定为V3版本，即配置SignatureMethod参数为TC3-HMAC-SHA256。

        :param request: Request instance for RecognizeCarPro.
        :type request: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarProRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.RecognizeCarProResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("RecognizeCarPro", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.RecognizeCarProResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SearchImage(self, request):
        """本接口用于对一张图片，在指定图片库中检索出与之相似的图片列表。

        >
        - 可前往 [图像搜索](https://cloud.tencent.com/document/product/1589) 产品文档中查看更多产品信息。

        :param request: Request instance for SearchImage.
        :type request: :class:`tencentcloud.tiia.v20190529.models.SearchImageRequest`
        :rtype: :class:`tencentcloud.tiia.v20190529.models.SearchImageResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SearchImage", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SearchImageResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM签名/鉴权错误。
AUTHFAILURE = 'AuthFailure'

# 内部错误。
INTERNALERROR = 'InternalError'

# 请求控制器发生错误。
INTERNALERROR_CONTROLREQUESTERROR = 'InternalError.ControlRequestError'

# 设备密钥已存在。
INTERNALERROR_DUPLICATEDATAKEY = 'InternalError.DuplicateDataKey'

# 设备名已存在。
INTERNALERROR_DUPLICATEDEVICENAME = 'InternalError.DuplicateDeviceName'

# 文件读写异常。
INTERNALERROR_FILEIOERROR = 'InternalError.FileIOError'

# 智研流量数据请求错误。
INTERNALERROR_NETWORKINFOREQUESTERROR = 'InternalError.NetworkInfoRequestError'

# 预置密钥尚未创建。
INTERNALERROR_UNDEFINEDENCRYPTEDKEY = 'InternalError.UndefinedEncryptedKey'

# 参数错误。
INVALIDPARAMETER = 'InvalidParameter'

# 参数取值错误。
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# 无法获取到可加速的运营商信息
INVALIDPARAMETERVALUE_VENDORNOTFOUND = 'InvalidParameterValue.VendorNotFound'

# 缺少参数错误。
MISSINGPARAMETER = 'MissingParameter'

# 操作被拒绝。
OPERATIONDENIED = 'OperationDenied'

# 不建议加速。
OPERATIONDENIED_ACCELERATIONNOTSUGGEST = 'OperationDenied.AccelerationNotSuggest'

# 中国电信加速token过期。
OPERATIONDENIED_CTCCTOKENEXPIRED = 'OperationDenied.CTCCTokenExpired'

# 相同加速间隔时间过短。
OPERATIONDENIED_CREATEQOSEXCEEDLIMIT = 'OperationDenied.CreateQosExceedLimit'

# 请求运营商加速超时。
OPERATIONDENIED_REQUESTQOSTIMEOUT = 'OperationDenied.RequestQosTimeout'

# 该用户加速已取消，不处于加速状态。
OPERATIONDENIED_USERNONACCELERATED = 'OperationDenied.UserNonAccelerated'

# 该用户不在运营商网络可加速范围内
OPERATIONDENIED_USEROUTOFCOVERAGE = 'OperationDenied.UserOutOfCoverage'

# 运营商返回结果错误。
OPERATIONDENIED_VENDORRETURNERROR = 'OperationDenied.VendorReturnError'

# 运营商服务器临时错误。
OPERATIONDENIED_VENDORSERVERERROR = 'OperationDenied.VendorServerError'

# 请求的次数超过了频率限制。
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# 资源不可用。
RESOURCEUNAVAILABLE = 'ResourceUnavailable'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class GetIndustryV1HomeMembersReqPayload(AbstractModel):
    """获取成员列表入参payload

    """

    def __init__(self):
        r"""
        :param ID: 用户ID
        :type ID: str
        """
        self.ID = None


    def _deserialize(self, params):
        self.ID = params.get("ID")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRequest(AbstractModel):
    """GetIndustryV1HomeMembers请求参数结构体

    """

    def __init__(self):
        r"""
        :param Payload: 无
        :type Payload: :class:`tencentcloud.icr.v20211014.models.GetIndustryV1HomeMembersReqPayload`
        :param Metadata: 无
        :type Metadata: :class:`tencentcloud.icr.v20211014.models.ReqMetadata`
        """
        self.Payload = None
        self.Metadata = None


    def _deserialize(self, params):
        if params.get("Payload") is not None:
            self.Payload = GetIndustryV1HomeMembersReqPayload()
            self.Payload._deserialize(params.get("Payload"))
        if params.get("Metadata") is not None:
            self.Metadata = ReqMetadata()
            self.Metadata._deserialize(params.get("Metadata"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespData(AbstractModel):
    """获取成员列表回包DataList

    """

    def __init__(self):
        r"""
        :param EditTime: 修改时间
注意：此字段可能返回 null，表示取不到有效值。
        :type EditTime: int
        :param FeatureList: 功能列表
注意：此字段可能返回 null，表示取不到有效值。
        :type FeatureList: :class:`tencentcloud.icr.v20211014.models.GetIndustryV1HomeMembersRespFeature`
        :param ID: 用户ID
注意：此字段可能返回 null，表示取不到有效值。
        :type ID: str
        :param IndustryType: 用户行业分类
注意：此字段可能返回 null，表示取不到有效值。
        :type IndustryType: str
        :param MemberNum: 子用户数量
注意：此字段可能返回 null，表示取不到有效值。
        :type MemberNum: int
        :param ProductList: 机器人列表
注意：此字段可能返回 null，表示取不到有效值。
        :type ProductList: :class:`tencentcloud.icr.v20211014.models.GetIndustryV1HomeMembersRespProduct`
        :param Remark: 备注
注意：此字段可能返回 null，表示取不到有效值。
        :type Remark: str
        :param Status: 是否有效
注意：此字段可能返回 null，表示取不到有效值。
        :type Status: int
        :param TypeList: 功能列表
注意：此字段可能返回 null，表示取不到有效值。
        :type TypeList: :class:`tencentcloud.icr.v20211014.models.GetIndustryV1HomeMembersRespType`
        :param UserAccount: 用户账号
注意：此字段可能返回 null，表示取不到有效值。
        :type UserAccount: str
        """
        self.EditTime = None
        self.FeatureList = None
        self.ID = None
        self.IndustryType = None
        self.MemberNum = None
        self.ProductList = None
        self.Remark = None
        self.Status = None
        self.TypeList = None
        self.UserAccount = None


    def _deserialize(self, params):
        self.EditTime = params.get("EditTime")
        if params.get("FeatureList") is not None:
            self.FeatureList = GetIndustryV1HomeMembersRespFeature()
            self.FeatureList._deserialize(params.get("FeatureList"))
        self.ID = params.get("ID")
        self.IndustryType = params.get("IndustryType")
        self.MemberNum = params.get("MemberNum")
        if params.get("ProductList") is not None:
            self.ProductList = GetIndustryV1HomeMembersRespProduct()
            self.ProductList._deserialize(params.get("ProductList"))
        self.Remark = params.get("Remark")
        self.Status = params.get("Status")
        if params.get("TypeList") is not None:
            self.TypeList = GetIndustryV1HomeMembersRespType()
            self.TypeList._deserialize(params.get("TypeList"))
        self.UserAccount = params.get("UserAccount")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespFeature(AbstractModel):
    """获取成员列表接口回包Feature

    """

    def __init__(self):
        r"""
        :param FeatureName: 功能名称
注意：此字段可能返回 null，表示取不到有效值。
        :type FeatureName: str
        :param ID: 功能ID
注意：此字段可能返回 null，表示取不到有效值。
        :type ID: str
        """
        self.FeatureName = None
        self.ID = None


    def _deserialize(self, params):
        self.FeatureName = params.get("FeatureName")
        self.ID = params.get("ID")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespIndustry(AbstractModel):
    """获取成员列表回包Industry

    """

    def __init__(self):
        r"""
        :param ID: 行业ID
注意：此字段可能返回 null，表示取不到有效值。
        :type ID: str
        :param IndustryName: 行业名称
注意：此字段可能返回 null，表示取不到有效值。
        :type IndustryName: str
        """
        self.ID = None
        self.IndustryName = None


    def _deserialize(self, params):
        self.ID = params.get("ID")
        self.IndustryName = params.get("IndustryName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespPayload(AbstractModel):
    """获取成员列表回包Payload

    """

    def __init__(self):
        r"""
        :param AccountLevel: 用户级别
注意：此字段可能返回 null，表示取不到有效值。
        :type AccountLevel: str
        :param DataList: 用户列表
注意：此字段可能返回 null，表示取不到有效值。
        :type DataList: list of GetIndustryV1HomeMembersRespData
        :param Limit: 每页数量
注意：此字段可能返回 null，表示取不到有效值。
        :type Limit: int
        :param Offset: 分页偏移量，从0开始
注意：此字段可能返回 null，表示取不到有效值。
        :type Offset: int
        :param Total: 用户总数
注意：此字段可能返回 null，表示取不到有效值。
        :type Total: int
        """
        self.AccountLevel = None
        self.DataList = None
        self.Limit = None
        self.Offset = None
        self.Total = None


    def _deserialize(self, params):
        self.AccountLevel = params.get("AccountLevel")
        if params.get("DataList") is not None:
            self.DataList = []
            for item in params.get("DataList"):
                obj = GetIndustryV1HomeMembersRespData()
                obj._deserialize(item)
                self.DataList.append(obj)
        self.Limit = params.get("Limit")
        self.Offset = params.get("Offset")
        self.Total = params.get("Total")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespProduct(AbstractModel):
    """获取成员列表接口回包ProductList

    """

    def __init__(self):
        r"""
        :param CreateTime: 创建时间
注意：此字段可能返回 null，表示取不到有效值。
        :type CreateTime: str
        :param EditTime: 编辑时间
注意：此字段可能返回 null，表示取不到有效值。
        :type EditTime: str
        :param AppKey: 机器人ID（AppKey信息）
注意：此字段可能返回 null，表示取不到有效值。
        :type AppKey: str
        :param Image: 机器人图标
注意：此字段可能返回 null，表示取不到有效值。
        :type Image: str
        :param Industry: 行业信息
注意：此字段可能返回 null，表示取不到有效值。
        :type Industry: list of GetIndustryV1HomeMembersRespIndustry
        :param OperatorList: 操作员列表
注意：此字段可能返回 null，表示取不到有效值。
        :type OperatorList: str
        :param ProductName: 机器人名字
注意：此字段可能返回 null，表示取不到有效值。
        :type ProductName: str
        :param Remark: 备注
注意：此字段可能返回 null，表示取不到有效值。
        :type Remark: str
        :param TemplateList: 模板列表
注意：此字段可能返回 null，表示取不到有效值。
        :type TemplateList: str
        """
        self.CreateTime = None
        self.EditTime = None
        self.AppKey = None
        self.Image = None
        self.Industry = None
        self.OperatorList = None
        self.ProductName = None
        self.Remark = None
        self.TemplateList = None


    def _deserialize(self, params):
        self.CreateTime = params.get("CreateTime")
        self.EditTime = params.get("EditTime")
        self.AppKey = params.get("AppKey")
        self.Image = params.get("Image")
        if params.get("Industry") is not None:
            self.Industry = []
            for item in params.get("Industry"):
                obj = GetIndustryV1HomeMembersRespIndustry()
                obj._deserialize(item)
                self.Industry.append(obj)
        self.OperatorList = params.get("OperatorList")
        self.ProductName = params.get("ProductName")
        self.Remark = params.get("Remark")
        self.TemplateList = params.get("TemplateList")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersRespType(AbstractModel):
    """获取成员列表接口回包TypeList

    """

    def __init__(self):
        r"""
        :param Type: 类型ID
注意：此字段可能返回 null，表示取不到有效值。
        :type Type: str
        :param TypeName: 类型名称
注意：此字段可能返回 null，表示取不到有效值。
        :type TypeName: str
        """
        self.Type = None
        self.TypeName = None


    def _deserialize(self, params):
        self.Type = params.get("Type")
        self.TypeName = params.get("TypeName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class GetIndustryV1HomeMembersResponse(AbstractModel):
    """GetIndustryV1HomeMembers返回参数结构体

    """

    def __init__(self):
        r"""
        :param Metadata: 无
注意：此字段可能返回 null，表示取不到有效值。
        :type Metadata: :class:`tencentcloud.icr.v20211014.models.RspMetadata`
        :param Payload: 无
注意：此字段可能返回 null，表示取不到有效值。
        :type Payload: :class:`tencentcloud.icr.v20211014.models.GetIndustryV1HomeMembersRespPayload`
        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
        :type RequestId: str
        """
        self.Metadata = None
        self.Payload = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Metadata") is not None:
            self.Metadata = RspMetadata()
            self.Metadata._deserialize(params.get("Metadata"))
        if params.get("Payload") is not None:
            self.Payload = GetIndustryV1HomeMembersRespPayload()
            self.Payload._deserialize(params.get("Payload"))
        self.RequestId = params.get("RequestId")


class ReqMetadata(AbstractModel):
    """请求的Metadata

    """

    def __init__(self):
        r"""
        :param ChannelID: 渠道
        :type ChannelID: str
        :param BusinessName: 无
        :type BusinessName: str
        :param GUID: 无
        :type GUID: str
        :param AppKey: 无
        :type AppKey: str
        :param LBS: 位置定位服务
        :type LBS: :class:`tencentcloud.icr.v20211014.models.ReqMetadataLBS`
        :param Vagrants: 透传字段
        :type Vagrants: list of ReqMetadataVagrant
        """
        self.ChannelID = None
        self.BusinessName = None
        self.GUID = None
        self.AppKey = None
        self.LBS = None
        self.Vagrants = None


    def _deserialize(self, params):
        self.ChannelID = params.get("ChannelID")
        self.BusinessName = params.get("BusinessName")
        self.GUID = params.get("GUID")
        self.AppKey = params.get("AppKey")
        if params.get("LBS") is not None:
            self.LBS = ReqMetadataLBS()
            self.LBS._deserialize(params.get("LBS"))
        if params.get("Vagrants") is not None:
            self.Vagrants = []
            for item in params.get("Vagrants"):
                obj = ReqMetadataVagrant()
                obj._deserialize(item)
                self.Vagrants.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ReqMetadataLBS(AbstractModel):
    """请求参数的lbs

    """

    def __init__(self):
        r"""
        :param Latitude: 纬度
        :type Latitude: float
        :param Longitude: 经度
        :type Longitude: float
        """
        self.Latitude = None
        self.Longitude = None


    def _deserialize(self, params):
        self.Latitude = params.get("Latitude")
        self.Longitude = params.get("Longitude")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ReqMetadataVagrant(AbstractModel):
    """请求参数Vagrant

    """

    def __init__(self):
        r"""
        :param Key: 无
        :type Key: str
        :param Value: 无
        :type Value: str
        """
        self.Key = None
        self.Value = None


    def _deserialize(self, params):
        self.Key = params.get("Key")
        self.Value = params.get("Value")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RspMetadata(AbstractModel):
    """回包的meta data

    """

    def __init__(self):
        r"""
        :param Code: 无
        :type Code: int
        :param Message: 无
        :type Message: str
        :param SessionID: 无
        :type SessionID: str
        :param SessionDelta: 无
        :type SessionDelta: str
        """
        self.Code = None
        self.Message = None
        self.SessionID = None
        self.SessionDelta = None


    def _deserialize(self, params):
        self.Code = params.get("Code")
        self.Message = params.get("Message")
        self.SessionID = params.get("SessionID")
        self.SessionDelta = params.get("SessionDelta")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        